@@ -30,6 +30,8 @@ using System.Collections;
 using System.Diagnostics;
 using Beagle.Util;
 
+using Mono.Posix;
+
 namespace Beagle.Tile {
 
 	[HitFlavor (Name="Conversations", Rank=900, Emblem="emblem-im-log.png", Color="#e5f5ef",
@@ -71,11 +73,11 @@ namespace Beagle.Tile {
 				Template ["nice_duration"] = "";
 
 			if (email != null)
-				Template ["SendMailAction"] = "Send Mail";
+				Template ["SendMailAction"] = Catalog.GetString ("Send Mail");
 
 			// FIXME: This is a temporary hack until gaim supports other protocols than AIM via gaim-remote
 			if (Hit ["fixme:protocol"] == "aim")
-				Template ["SendIMAction"] = "Send IM";
+				Template ["SendIMAction"] = Catalog.GetString ("Send IM");
 			
 			if (buddy != null && buddy.Alias != "")
 				speaking_alias = buddy.Alias;
@@ -84,9 +86,9 @@ namespace Beagle.Tile {
 
 			// FIXME: Hack to figure out if the conversation is taken place in a chat room
 			if (Hit["fixme:speakingto"].EndsWith (".chat"))
-				Template["title"] = String.Format ("Conversation in {0}", speaking_alias.Replace(".chat",""));
+				Template["title"] = String.Format (Catalog.GetString ("Conversation in {0}"), speaking_alias.Replace(".chat",""));
 			else
-				Template["title"] = String.Format ("Conversation with {0}", speaking_alias);
+				Template["title"] = String.Format (Catalog.GetString ("Conversation with {0}"), speaking_alias);
 
 
 			if (buddy != null && buddy.BuddyIconLocation != "") {
@@ -160,6 +162,7 @@ namespace Beagle.Tile {
 			return null;
 		}
 
+#if false
 		private string HighlightOrNull (string haystack, string [] needles)
 		{
 			string [] highlight_start_list = {"<font color=red>",
@@ -201,6 +204,7 @@ namespace Beagle.Tile {
 			else
 				return null;
 		}
+#endif
 
 		[TileAction]
 		public override void Open ()
@@ -209,7 +213,8 @@ namespace Beagle.Tile {
 			Process p = new Process ();
 			p.StartInfo.UseShellExecute = true;
 			p.StartInfo.FileName = "beagle-imlogviewer";
-			p.StartInfo.Arguments = Hit ["fixme:file"];
+			p.StartInfo.Arguments = String.Format ("--highlight-search \"{0}\" {1}",
+							       Query.QuotedText, Hit ["fixme:file"]);
 
 			try {
 				p.Start ();
@@ -228,9 +233,6 @@ namespace Beagle.Tile {
 		[TileAction]
 		public void SendIm ()
 		{
-			if (Hit ["fixme:protocol"] != "aim")
-				return;
-			
 			SendImAim (Hit ["fixme:speakingto"]);
 		}
 	}
