@@ -42,11 +42,9 @@ namespace Beagle.Util.AudioUtil {
 			private int blockType, dataLength;
 			private bool lastBlock;
 			private byte[] data;
-			private byte[] bytes;
 			
 			public MetadataBlockHeader (byte[] b) {
-				this.bytes = b;
-				
+
 				lastBlock = ( (b[0] & 0x80) >> 7 ) == 1;
 				
 				int type = b[0] & 0x7F;
@@ -134,8 +132,6 @@ namespace Beagle.Util.AudioUtil {
 			if (flac != "fLaC")
 				throw new Exception ("fLaC Header not found, not a flac file");
 			
-			Tag tag = null;
-			
 			// Seems like we hava a valid stream
 			bool isLastBlock = false;
 			while (!isLastBlock) {
