@@ -45,10 +45,14 @@ namespace Beagle.Daemon.FileSystemQueryable {
 
 		private static Logger log = Logger.Get ("FileSystemQueryable");
 
+		// History:
+		// 1: Initially set to force a reindex due to NameIndex changes.
+		const int MINOR_VERSION = 1;
+
 		private IFileEventBackend event_backend;
 		private FileSystemModel model;
 
-		public FileSystemQueryable () : base ("FileSystemIndex")
+		public FileSystemQueryable () : base ("FileSystemIndex", MINOR_VERSION)
 		{
 		}
 
@@ -271,12 +275,8 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		public void StartWorker ()
 		{
 			event_backend.Start (this);
-
-			// FIXME: Shouldn't be hard-wired
-			model.AddRoot (PathFinder.HomeDir);
-
+			Conf.Subscribe (typeof (Conf.IndexingConfig), model.LoadConf);
 			log.Info ("FileSystemQueryable start-up thread finished");
-			
 			// FIXME: Do we need to re-run queries when we are fully started?
 		}
 
